@@ -28,10 +28,6 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#ifdef GDK_WINDOWING_X11
-#include <gdk/gdkx.h>
-#endif
-
 #include "devhelp.h"
 #include "dh-app.h"
 
@@ -39,7 +35,6 @@ static gboolean  option_new_window;
 static gchar    *option_search;
 static gchar    *option_search_assistant;
 static gboolean  option_quit;
-static gboolean  option_focus_search;
 static gboolean  option_version;
 
 static GOptionEntry options[] = {
@@ -48,11 +43,6 @@ static GOptionEntry options[] = {
           N_("Opens a new Devhelp window"),
           NULL
         },
-        { "focus-search",       'f',
-          0, G_OPTION_ARG_NONE, &option_focus_search,
-          N_("Focus the Devhelp window with the search field active"),
-          NULL
-        },
         { "search", 's',
           0, G_OPTION_ARG_STRING, &option_search,
           N_("Search for a keyword"),
@@ -89,8 +79,6 @@ run_action (DhApp *application,
                 dh_app_search (application, option_search);
         } else if (option_search_assistant) {
                 dh_app_search_assistant (application, option_search_assistant);
-        } else if (option_focus_search) {
-                dh_app_focus_search (application);
         } else {
                 if (is_remote)
                         dh_app_raise (application);
@@ -114,22 +102,6 @@ main (int argc, char **argv)
         GError  *error = NULL;
         gint     status;
 
-#ifdef GDK_WINDOWING_QUARTZ
-        {
-                gint i;
-
-                for (i = 0; i < argc; i++) {
-                        if (g_str_has_prefix (argv[i], "-psn_")) {
-                                for (; i < argc-1; i++) {
-                                        argv[i] = argv[i+1];
-                                }
-                                argc--;
-                                break;
-                        }
-                }
-        }
-#endif
-
         setlocale (LC_ALL, "");
         bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
